
class Module1(object):

    def __init__(self):
        x = 0

    def func1(a, b):
        return a + b